(* Js_of_ocaml compiler
 * http://www.ocsigen.org/js_of_ocaml/
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, with linking exception;
 * either version 2.1 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *)

type trampolined_calls = Code.Var.Set.t

val remove_empty_blocks : live_vars:Deadcode.variable_uses -> Code.program -> Code.program

type in_cps = Code.Var.Set.t

val f :
     flow_info:Global_flow.info
  -> live_vars:Deadcode.variable_uses
  -> Code.program
  -> Code.program * trampolined_calls * in_cps
